import { Image, Input, ScrollView, Text, View } from '@tarojs/components'
import { memo, useCallback, useEffect, useMemo, useRef, useState } from 'react'
import classnames from 'classnames'
import styles from './index.module.scss'
import LabAndImg from '@/components/LabAndImg'
import { formatPriceDiv, formatWeightDiv } from '@/common/format'
import { EnumSaleMode } from '@/common/Enumerate'

interface props {
  clickAdd: (any) => void
  clickReduce: (any) => void
  handPlus: (any) => void
  modeFont?: number
  value: {
    showInput?: boolean
    nums?: string
    bulk_price?: Number
    length_cut_price?: Number
    weight_cut_price?: Number
    code?: string
    rgb?: { r: number; g: number; b: number }
    lab?: { l: number; a: number; b: number }
    texture_url: string
    name?: string
    roll?: number | string
    buyNums?: number | string
    id?: number
    weight_error?: number | string
    last_bulk_price?: number
    last_length_cut_price?: number
    last_weight_cut_price?: number
  }
  goodList?: any[]
  onBlur?: (a: any, c: any) => void
}
const GoodsItem = (props: props) => {
  const {
    clickAdd,
    clickReduce,
    handPlus,
    modeFont,
    value: valueInfo,
    onBlur,
  } = props

  const [value, setValue] = useState<any>({ count: valueInfo.nums })
  console.log(value.count, 'value.count')

  const onInputEven = (e) => {
    const res = e.detail.value
    if (modeFont == 0) {
      if (Number(res) < 1) {
        setValue({ count: '' })
      }
    }
    if (modeFont == 1) {
      if (Number(res) < 0) {
        setValue({ count: '' })
      }
    }
    if (modeFont == 2) {
      if (Number(res) < 0) {
        setValue({ count: '' })
      }
    }
  }

  const type = useMemo(() => {
    if (modeFont === 0) {
      return 'number'
    }
    else {
      return 'digit'
    }
  }, [modeFont])

  const labAndImgObj = useCallback((item) => {
    return { lab: item.lab, rgb: item.rgb, texture_url: item.texture_url }
  }, [])

  return (
    <View className={styles.goodsBox}>
      <View className={styles.pic}>
        <LabAndImg value={labAndImgObj(valueInfo)} />
      </View>
      <View className={styles.rightGoodbox}>
        <View className={styles.leftFontsbox}>
          <View className={styles.title}>{valueInfo?.code} {valueInfo?.name}</View>
          <View className={styles.productNums}>剩：{valueInfo?.roll}件</View>
          {
            modeFont === EnumSaleMode.Bulk && <View className={styles.productName}>空差：{formatWeightDiv(valueInfo?.weight_error) || 0}Kg</View>
          }
        </View>
        <View className={styles.rightFontsbox}>
          <View className={styles.moneyFlex}>
            {
              (modeFont === EnumSaleMode.Bulk) && (valueInfo?.last_bulk_price !== valueInfo?.bulk_price)
                ? <View className={styles.lastBox}>
                ¥{formatPriceDiv(valueInfo?.last_bulk_price)} /Kg
                </View>
                : null
            }
            <View className={styles.money}>¥{modeFont === EnumSaleMode.Bulk ? formatPriceDiv(valueInfo?.bulk_price) : modeFont === EnumSaleMode.Plate ? formatPriceDiv(valueInfo?.length_cut_price) : formatPriceDiv(valueInfo?.weight_cut_price)}{modeFont !== EnumSaleMode.Plate ? '/Kg' : '/m'}</View>
          </View>
          {
            valueInfo.showInput
              ? <View className={styles.inputBox}>
                <View className={styles.reduceBox} onClick={() => { clickReduce?.(valueInfo) }}>
                  <View className={styles.reduce}></View>
                </View>
                <View className={styles.numsBox}>
                  <Input alwaysEmbed cursorSpacing={100} adjustPosition type={type as any} value={value.count} onInput={onInputEven} onBlur={e => onBlur?.(e, valueInfo.id)}></Input>
                </View>
                <View className={styles.addBox} onClick={() => handPlus?.(valueInfo)}>+</View>
              </View>
              : <View className={styles.addtine} onClick={() => clickAdd?.(valueInfo)}>+</View>
          }
        </View>
      </View>
    </View>
  )
}
export default memo(GoodsItem)
