import { Button, CustomWrapper, ScrollView, View } from '@tarojs/components'
import Taro, { nextTick, useDidShow } from '@tarojs/taro'
import { forwardRef, memo, useCallback, useEffect, useImperativeHandle, useLayoutEffect, useMemo, useRef, useState } from 'react'
import classnames from 'classnames'
import VirtualList from '@tarojs/components/virtual-list'
import Big from 'big.js'
import Divider from '../Divider'
import NormalButton from '../normalButton'
import InfiniteScroll from '../infiniteScroll'
import styles from './index.module.scss'
import Goods from './goodsItem/index'
import Search from '@/components/search'
import Popup from '@/components/popup'
import DotLoading from '@/components/dotLoading'
import { formatDateTime, formatHashTag, formatMeterMul, formatPriceDiv, formatRemoveHashTag, formatWeightDiv } from '@/common/format'
import { goLink, isInteger } from '@/common/common'
import { EnumSaleMode } from '@/common/Enumerate'
import { MpProductColorList, MpShoppingCartProductColorList } from '@/api/order'
import { dataLoadingStatus, debounce, getFilterData } from '@/common/util'
import { selectList } from '@/common/Enumerate/BaseEnum'

interface RowPropsType{
  item: any
  saleMode: EnumSaleMode
  onBlur: (item: any) => void
  handPlus: (item: any) => void
  reduceNums: (item: any) => void
  handAdd: (item: any) => void
}

const rows = ({
  item,
  saleMode,
  onBlur,
  handPlus,
  reduceNums,
  handAdd,
}: RowPropsType) => {
  console.log('item', item)
  return (
    <Goods
      onBlur={onBlur}
      modeFont={saleMode}
      handPlus={handPlus}
      handleSubtract={reduceNums}
      value={item}
      clickAdd={handAdd}
    ></Goods>
  )
}
const MemoRows = memo(rows)

interface prosObj {
  showPopup?: boolean
  closePopup?: () => void
  obj?: {
    code?: string
    name?: string
  }
  clientName: string
  clientId: Number
}
const ShoppingCart = (props: prosObj, ref) => {
  const [modeFont, setModeFont] = useState<EnumSaleMode>(0)

  const [goodList, setGoodList] = useState<{ list: any[]; total: number }>({ list: [], total: 0 })

  const clearGoodsList = () => {
    setGoodList({ list: [], total: 0 })
  }

  const {
    showPopup = false,
    closePopup,
    obj = {},
    clientName = '',
    clientId = -1,
  } = props
  // 选择的类型
  const typeList = [
    {
      id: 0,
      name: '大货',
    },
    {
      id: 1,
      name: '剪版',
    },
    {
      id: 2,
      name: '散剪',
    },
  ]

  const SearchRef = useRef<any>()

  useImperativeHandle(ref, () => ({
    SearchRef,
    setSearchObj,
  }))

  // 已选的颜色
  // const selectTotal = useMemo(() => {
  //   return multipleSelection.current.length
  // }, [goodList])

  const [multipleSelection, setMultipleSelection] = useState<any[]>([])

  // 选择的条数或者米数
  const selectNums = useMemo(() => {
    return multipleSelection.reduce((prev, cur) => Big(prev).add(Number(cur.nums)).toNumber(), 0)
  }, [multipleSelection])

  const isDisabled = useMemo(() => {
    return !(multipleSelection.length > 0 && clientName !== '')
  }, [clientName, multipleSelection])

  const navTo = () => {
    Taro.navigateTo({
      url: `/pages/customerPage/index?clientId=${clientId}`,
    })
  }

  const handBuyNow = () => {
    console.log('goodList', goodList, modeFont, multipleSelection)
    const checkedGoodsKind = multipleSelection.map(item => ({
      id: item.id,
      length: modeFont !== EnumSaleMode.Bulk ? formatMeterMul(item?.nums) : 0,
      roll: modeFont === EnumSaleMode.Bulk ? item.nums : 0,
      sale_price: formatPriceDiv(item?.sale_price),
    }))
    goLink('/pages/submitOrder/index', {
      purchaser_id: clientId,
      sale_mode: modeFont,
      sale_order_product_color_list: JSON.stringify(checkedGoodsKind),
      purchaser_name: clientName,
      isBuyNew: true,
    })
  }

  useEffect(() => {
    console.log('shoppingCart useEffect')
  }, [])

  // 点击加展示输入框
  const handAdd = useCallback((item) => {
    console.log('handAdd item', item)
    console.log('multipleSelection', multipleSelection)
    setMultipleSelection((prev) => {
      return [...prev, item]
    })
  }, [multipleSelection])

  // 点击减
  const reduceNums = useCallback((current) => {
    console.log('reduceNums', current)
    if (current.checked) {
      setMultipleSelection(prev => prev.map((it) => {
        if (it.id === current.id) {
          it.nums = Number(current.nums)
        }
        return it
      }))
    }
    else {
      setMultipleSelection(prev => prev.filter(it => it.id !== current.id))
    }
  }, [])

  const onj = JSON.parse(Taro.getStorageSync('userInfo') || '{}')

  const [search, setSearchObj] = useState({
    page: 1,
    size: 10,
    modeId: 0,
    goodsId: null,
    code_or_name: '',
    physical_warehouse: onj.physical_warehouse,
    purchaser_id: -1,
  })

  // 选择类型
  const handCheckMode = (item) => {
    setSearchObj(e => ({ ...e, modeId: item.id }))
    setModeFont(item.id)
    clearGoodsList()
    setMultipleSelection([])
  }
  // 清空
  useEffect(() => {
    console.log('search', search)
    if (showPopup) {
      setMultipleSelection([])
      clearGoodsList()
    }
  }, [showPopup])

  // 监听选择的类型
  useEffect(() => {
    console.log('search', search)
    if (search.goodsId) {
      getGoodList()
    }
  }, [search, showPopup])

  const { fetchData: colorlistFetch, state } = MpProductColorList()
  const getGoodList = async() => {
    const res = await colorlistFetch({
      page: search.page,
      size: search.size,
      product_id: search.goodsId,
      sale_mode: search.modeId,
      code_or_name: search.code_or_name,
      physical_warehouse: search?.physical_warehouse,
      purchaser_id: clientId,
    })
    res.data.list.map((item) => {
      item.nums = selectList[item.id] ? selectList[item.id].defaultNum : 0
      return item
    })
    setRefresherTriggeredStatus(false)
    setGoodList({ list: res.data.list, total: res.data.total })
  }

  // 点击输入框的加
  const handPlus = useCallback((current) => {
    console.log('handPlus current', current)
    setMultipleSelection(prev => prev.map((it) => {
      if (it.id === current.id) {
        it.nums = current.nums
      }
      return it
    }))
  }, [])

  // 输入框失焦
  const onBlur = useCallback((current) => {
    reduceNums(current)
  }, [])

  // 输入了搜索关键字
  const getSearchData = debounce((eq) => {
    setSearchObj(e => ({ ...e, code_or_name: eq }))
  }, 300)

  const handleClosePopup = () => {
    closePopup?.()
    clearGoodsList()
    setMultipleSelection([])
  }

  // 加入购物车
  const { fetchData: preViewFetch } = MpShoppingCartProductColorList()
  const handSure = async() => {
    const list: any[] = []
    multipleSelection.forEach((it) => {
      console.log('multipleSelection', it)
      list.push({
        roll: search.modeId === 0 ? Number(it.nums) : 0,
        length: search.modeId !== 0 ? formatMeterMul(it.nums) : 0,
        product_color_id: Number(it.id),
      })
    })
    const query = {
      purchaser_id: clientId,
      sale_mode: search.modeId,
      color_list: list,
      sale_offect: 0,
    }
    const res = await preViewFetch(getFilterData(query))
    Taro.showLoading({
      mask: true,
      title: '请稍等...',
    })
    if (res.data) {
      Taro.showToast({
        title: '加入成功',
        duration: 2000,
      })
      handleClosePopup()
      Taro.hideLoading()
    }
    else {
      Taro.hideLoading()
      Taro.showToast({
        icon: 'error',
        title: res.msg,
        duration: 2000,
      })
    }
  }

  // 上拉加载数据
  const pageNum = useRef({ size: search.size, page: search.page })

  // 数据加载状态
  const statusMore = useMemo(() => {
    return dataLoadingStatus({ list: goodList.list, total: goodList.total, status: state.loading! })
  }, [goodList, state])

  const getScrollToLower = useCallback(() => {
    if (goodList.list.length < goodList.total) {
      pageNum.current.page++
      const size = pageNum.current.size * pageNum.current.page
      setSearchObj(e => ({ ...e, size }))
      console.log(search, 11111)
    }
  }, [goodList])

  // 列表下拉刷新
  const [refresherTriggeredStatus, setRefresherTriggeredStatus] = useState(false)

  const getRefresherRefresh = async() => {
    pageNum.current.page = 1
    setRefresherTriggeredStatus(true)
    setSearchObj(val => ({ ...val, size: 10 }))
  }

  return (
    <Popup showTitle={false} show={showPopup} onClose={closePopup}>
      <View className={styles.popupHeight}>
        <View className={styles.shopcartBox} id="shopCartBox">
          <View className={styles.topTitle}>
            {formatHashTag(obj?.code, obj?.name)}
          </View>
          <View className={styles.selectFont}>
            已选 1 种面料，{multipleSelection.length} 个颜色，共 {selectNums} {modeFont === EnumSaleMode.Bulk ? '条' : '米'}
          </View>
          <View className={styles.flexType}>
            {typeList.map((item, index) => {
              return (
                <View
                  onClick={() => handCheckMode?.(item)}
                  key={index}
                  className={classnames(item.id === modeFont ? styles.activemodeFont : null, styles.modeFont)}
                >
                  {item.name}
                </View>
              )
            })}
          </View>
          <View className={styles.searchBar}>
            <Divider direction="horizontal" customStyles={{ margin: '12px 0' }}></Divider>
            <View className={styles.flexFonts}>
              <View className={styles.kingFont}>颜色分类({goodList.list?.length})</View>
              <View className={styles.danwei}>
                {modeFont == EnumSaleMode.Bulk ? '大货' : modeFont == EnumSaleMode.Plate ? '剪版' : '散剪'}单位：{modeFont === EnumSaleMode.Bulk ? '条' : '米'}
              </View>
            </View>
            <View className={styles.searchBox}>
              <Search
                ref={SearchRef}
                cursorSpacing={100}
                placeholder="请输入搜索布料"
                showBtn={false}
                changeOnSearch={getSearchData}
                adjustPosition
              />
            </View>
          </View>
          <View id="virtualListContainer" className={styles.virtualListContainer}>
            <CustomWrapper>
              <InfiniteScroll
                styleObj={{ boxSizing: 'border-box' }}
                statusMore={statusMore}
                lowerThresholdNum={100}
                selfonScrollToLower={getScrollToLower}
                refresherEnabled
                refresherTriggered={refresherTriggeredStatus}
                selfOnRefresherRefresh={getRefresherRefresh}
              >
                {
                  goodList.list.map((item, index) => {
                    return (
                      <MemoRows
                        item={item}
                        key={index}
                        handAdd={handAdd}
                        saleMode={modeFont}
                        reduceNums={reduceNums}
                        handPlus={handPlus}
                        onBlur={onBlur}
                      />
                    )
                  })
                }
              </InfiniteScroll>
            </CustomWrapper>
          </View>
        </View>
        <View className={styles.noBottom}>
          <View className={styles.bottomBox}>
            <View className={styles.leftBottom} onClick={navTo}>
              <View className={styles.nowFont}>当前客户：</View>
              <View className={styles.selctFont}>{clientName === '' ? '请选择客户 >' : `${clientName} >`}</View>
            </View>
            <View className={styles.rightBottom}>
              <NormalButton round type="primary" disabled={isDisabled} onClick={handBuyNow}>立即购买</NormalButton>
              <NormalButton round type="primary" disabled={isDisabled} onClick={handSure}>加入购物车</NormalButton>
            </View>
          </View >
        </View>
      </View>
    </Popup>
  )
}
export default memo(forwardRef(ShoppingCart))
