import { View } from '@tarojs/components'
import { useCallback } from 'react'
import styles from './index.module.scss'
import LabAndImg from '@/components/LabAndImg'
import Tag from '@/components/tag'
import { formatRemoveHashTag } from '@/common/format'
import Counter from '@/components/counter'
import Divider from '@/components/Divider'

interface PropsType {
  item: any
  onChangeCounter?: (value: number, id: number) => void
}

const ColorCardItem = (props: PropsType) => {
  const { item, onChangeCounter } = props
  const labAndImgObj = useCallback((item) => {
    return { lab: item?.lab, rgb: item?.rgb, texture_url: item?.texture_url }
  }, [])

  const handleCountChange = (value: number) => {
    onChangeCounter?.(value, item.id)
  }

  return <View className={styles.colorCardBottom} key={item.id}>
    <View style={{ minWidth: '24%' }}>
      <View className={styles.leftCont}>
        <LabAndImg value={labAndImgObj(item)} />
      </View>
    </View>
    <View className={styles.rightCont}>
      <View className={styles.rightCont__top}>
        {item.color_card_name}
      </View>
      <View className={styles.rightCont__bottom}>
        <View className={styles.rightCont__left}>
          {
            item.affiliation_product.map((product_color, index) => {
              return <Tag customStyle={{ marginRight: '5px', marginBottom: '2px', padding: '5px', background: '#e3ecff', color: '#558cff', borderColor: '#e3ecff' }} key={index} size="small" circle>{formatRemoveHashTag(product_color.code)}</Tag>
            })
          }
        </View>
        <View className={styles.rightCont__right}>
          <Counter
            defaultNum={item?.count || 1}
            onChange={handleCountChange}
            unit="本"
            minNum={0}
            maxNum={2}
          />
        </View>
      </View>
      <Divider direction="horizontal" customStyles={{ margin: '12px 0 0 ' }}></Divider>
    </View>
  </View>
}
export default ColorCardItem
