import { View } from '@tarojs/components'
import Taro, { useDidShow } from '@tarojs/taro'
import { useCallback, useEffect, useMemo, useRef, useState } from 'react'
import styles from './index.module.scss'
import Search from '@/components/search'
import SideBar from '@/components/sideBar'
import Product from '@/components/product'
import ShopCart from '@/components/shoppingCart'
import { goLink } from '@/common/common'
import { KindListApi, ProductListApi } from '@/api/index'
// import useLogin from '@/use/useLogin'
import { ClientListApi, MpProductColorList, MpShoppingCartProductColorList } from '@/api/order'
import { dataLoadingStatus, debounce, getFilterData } from '@/common/util'
import { useCheckTabBarSelectStatus } from '@/use/useCommon'
import { TabBarIndex } from '@/reducers/tabBar'

const limit = 6

const Index = () => {
  const product_kind_id_ref = useRef(0)
  // 获取客户
  const [clienList, setclienList] = useState<any[]>([])
  const { fetchData: listFetchData } = ClientListApi()
  // 列表下拉刷新
  const [refresherTriggeredStatus, setRefresherTriggeredStatus] = useState(false)

  const [clientObj, setclientObj] = useState({
    clientId: -1,
    clientName: '',
  })
  const getClient = async() => {
    const res = await listFetchData({
      page: 1, size: 10,
    })
    setclientObj({
      clientId: res.data.list?.length > 0 ? res.data.list[0]?.id : -1,
      clientName: res.data.list?.length > 0 ? res.data.list[0]?.name : '',
    })
    setclienList([...res.data.list])
  }

  const [filtrate, setFiltrate] = useState({ product_kind_id: 0, size: limit, page: 1 })
  // 获取面料种类
  const [kindData, setKindData] = useState<any>({ list: [], defaultId: 0 })
  const { fetchData } = KindListApi()
  const categoryList = async() => {
    const res = await fetchData()
    if (res.data?.list) {
      setKindData({ ...kindData, list: res.data.list, defaultId: res.data.list[0].id })
      setFiltrate({ ...filtrate, product_kind_id: res.data.list[0].id })
      product_kind_id_ref.current = res.data.list[0].id
    }
  }

  // 获取面料列表
  const [productData, setProductData] = useState({ list: [], total: 0 })
  const [hasMore, setHasMore] = useState(true)
  const pageNum = useRef({ size: filtrate.size, page: filtrate.page })
  const { fetchData: productFetchData, state: productState } = ProductListApi()
  // 获取数据方法
  const getProductList = async() => {
    const { data, total } = await productFetchData(filtrate)
    setProductData({ ...productData, list: data.list, total })
    setRefresherTriggeredStatus(() => false)
  }
  // 监听查询条件
  useEffect(() => {
    if (filtrate.product_kind_id) { getProductList() }
  }, [filtrate])

  // 点击面料类型
  const getProductKindId = useCallback((e) => {
    pageNum.current.page = 1
    setProductData({ list: [], total: 0 })
    setFiltrate(list => ({ ...list, size: limit, product_kind_id: e.id }))
    product_kind_id_ref.current = e.id
  }, [])

  // 上拉加载数据
  const getScrolltolower = useCallback(() => {
    if (productData.list.length >= productData.total) {
      setHasMore(false)
    }
    else {
      pageNum.current.page++
      const newSize = pageNum.current.size * pageNum.current.page
      setFiltrate(e => ({ ...e, size: newSize }))
    }
  }, [productData])

  const [showShopCart, setShowShopCart] = useState(false)

  const getRefresherRefresh = async() => {
    pageNum.current.page = 1
    setFiltrate({ ...filtrate, size: limit })
    setHasMore(true)
    setRefresherTriggeredStatus(true)
  }
  useEffect(() => {
    categoryList()
    getClient()
  }, [])

  const ShopCartRef = useRef<any>(null)

  const [goodObj, setGoodsobj] = useState({})
  // 点击对应商品显示购物车
  const showCart = async(item) => {
    ShopCartRef.current.setSearchObj(e => ({ ...e, goodsId: item.id, purchaser_id: clientObj?.clientId, code_or_name: '' }))
    ShopCartRef.current.SearchRef.current.setInputCon('')
    setShowShopCart(true)
    setGoodsobj(item)
  }

  // 关闭弹窗
  const closePoup = () => {
    setShowShopCart(false)
  }
  // 数据加载状态
  const statusMore = useMemo(() => {
    const status = dataLoadingStatus({ list: productData.list, total: productData.total, status: productState.loading! })
    console.log('loading status', status)
    return status
  }, [productData, productState.loading])

  useDidShow(() => {
    // 获取选择的客户
    const pages = Taro.getCurrentPages()
    const currPage = pages[pages.length - 1] // 获取当前页面
    // 判断是否有跳转选择客户
    if (currPage.data?.clientId && currPage.data?.clientId !== '') {
      setclientObj({
        clientId: currPage.data?.clientId,
        clientName: currPage.data?.clientName,
      })
      ShopCartRef.current.setSearchObj(val => ({ ...val, purchaser_id: currPage.data?.clientId }))
    }
    // 默认客户
    if (currPage.data?.clientId == null) {
      setclientObj({
        clientId: clienList.length > 0 ? clienList[0]?.id : -1,
        clientName: clienList.length > 0 ? clienList[0]?.name : '',
      })
    }
  })

  // 获取二级分类
  const product_kind_id_next_ref = useRef(0)
  const getSelectClassId = useCallback((id) => {
    pageNum.current.page = 1
    setProductData({ list: [], total: 0 })
    const kind_id = id == -1 ? product_kind_id_ref.current : id
    product_kind_id_next_ref.current = id
    setFiltrate(list => ({ ...list, size: limit, product_kind_id: kind_id }))
  }, [])

  useCheckTabBarSelectStatus(TabBarIndex.INDEX)

  return (
  // <MoveBtn onClick={() => setShowShopCart(showShopCart)}>
    <View className={styles.main}>
      <View className={styles.search}>
        {/* <View className={styles.search_collect} onClick={() => goLink('/pages/collection/index')}>
                        我的收藏
                    </View> */}
        <View className={styles.search_input} onClick={() => goLink('/pages/searchPage/index')}>
          <Search disabled style={{ width: '263rpx' }} />
        </View>
      </View>
      <View className={styles.products}>
        <SideBar
          list={kindData.list}
          height="100%"
          defaultValue={kindData.defaultId}
          hasMore={hasMore}
          statusMore={statusMore}
          selfOnScrolltolower={getScrolltolower}
          sideBarOnClick={getProductKindId}
          heightItem={150}
          selectClass={getSelectClassId}
          refresherTriggered={refresherTriggeredStatus}
          selfOnRefresherRefresh={getRefresherRefresh}
        >
          <Product productList={productData.list} popupShow={item => showCart(item)} />
        </SideBar>
      </View>
      <ShopCart
        clientName={clientObj?.clientName}
        clientId={clientObj?.clientId}
        obj={goodObj}
        ref={ShopCartRef}
        showPopup={showShopCart}
        closePopup={closePoup}
      ></ShopCart>
    </View>
  // </MoveBtn>
  )
}
export default Index
// oninputEvent={(e, item) => { oninputEvent(e, item) }}
