import { Button, Text, View } from '@tarojs/components'
import Taro, { useDidShow, usePullDownRefresh, useRouter } from '@tarojs/taro'
import type { ReactNode } from 'react'
import React, { memo, useCallback, useEffect, useMemo, useRef, useState } from 'react'
import classnames from 'classnames'
import OfflinePay from '../order/components/offlinePay'
import PayPopup from '../order/components/PayPopup'
import styles from './index.module.scss'
import AdvanceOrderState from './components/advanceOrderState'
import AddressDetailBox from './components/addressDetailBox'
import BottomApply from './components/BottomApply'
import OrderState from './components/orderState'
import Remark from '@/components/textareaEnhance'
import Popup from '@/components/popup'
import BottomBtns from '@/components/BottomBtns'
import { debounce } from '@/common/util'
import {
  GetPayCode,
  MpSaleOrder,
  MpSaleOrderAddress,
  MpSaleOrderCancel,
  MpSaleOrderPut,
  MpSaleOrderReceive,
  MpSaleOrderShipmentMode,
  MpShoppingCartProductColorList,
  OrderPaymentOrderPaymentMethodInfo,
  OrderPaymentOrderPaymentSubmission,
  OrderPaymentPreCollectOrderOrderPaymentMethodInfo,
  OrderPaymentPreCollectOrderOrderPaymentSubmission,
  PassAdjustPriceAudit,
  RefuseAdjustPriceAudit,
} from '@/api/order'
import { alert, goLink, paywayList } from '@/common/common'
import { formatDateTime, formatHashTag, formatImgUrl, formatMeterDiv, formatPriceDiv, formatRemoveHashTag, formatWeightDiv } from '@/common/format'
import IconFont from '@/components/iconfont/iconfont'
import { IMG_CND_Prefix, PAY_H5_CODE_URL } from '@/common/constant'
import SaleCodeList from '@/components/SaleCodeList'
import LabAndImg from '@/components/LabAndImg'
import Tag from '@/components/tag'
import { EnumSaleMode } from '@/common/Enumerate'
import NormalButton from '@/components/normalButton'
import Dialog from '@/components/Dialog'
import useUserInfo from '@/use/useUserInfo'

// 卡片盒子元素
interface Obs {
  title?: string
  modeName?: string
  showMode?: boolean
  children?: ReactNode
  clickNode?: () => void
}

const DefaultBox = (props: Obs) => {
  const {
    title = '标题',
    modeName = '大货',
    showMode = false,
    children,
    clickNode,
  } = props

  return (
    <View className={styles.defaltBox}>
      <View className={styles.titleBox}>
        <View className={styles.title}>{title}</View>
        {
          showMode && <View className={styles.modeName} onClick={() => clickNode?.()}>{modeName}</View>
        }
      </View>
      <View className={styles.modeLine}></View>
      {children}
    </View>
  )
}
const DefaultBoxWithMemo = memo(DefaultBox)

// 产品商品元素
interface PropGoods {
  // item?: {
  //     code?: string | number
  // }
  list: any[]
  obj: {
    sale_mode?: number | string
  }
}
const GoodsItem = (porps: PropGoods) => {
  const { list = [], obj = {} } = porps
  const labAndImgObj = useCallback((item) => {
    return { lab: item.lab, rgb: item.rgb, texture_url: item.texture_url }
  }, [])
  return (
    <>
      {
        list.map((item, index) => {
          return (
            <View className={styles.goodsBox} key={index}>
              <View className={styles.goodsProduct}>{item.code}# {item.name}</View>
              <View className={styles.goodsLine}></View>
              {
                item.product_colors.map((it, inx) => {
                  return (
                  // {/* 第一个版本的样式 */}

                  // <View className={styles.itemGoods} key={inx}>
                  //   <View className={styles.itemPic}>
                  //     <LabAndImg value={labAndImgObj(it)} />
                  //   </View>
                  //   <View className={styles.itemRight}>
                  //     <View className={styles.item_right_top}>
                  //       <View className={styles.itemName}>{formatHashTag(it.code, it.name)}</View>
                  //       <View className={styles.itemNums}>x{obj?.sale_mode === 0 ? it.roll : it.length / 100}{obj?.sale_mode === 0 ? '条' : 'm'}</View>
                  //     </View>
                  //     <View className={styles.item_right_Bottom}>
                  //       <View className={styles.flexBox}>
                  //         <View className={styles.itemMoney}>¥{formatPriceDiv(it.sale_price)}/{obj?.sale_mode === 1 ? 'm' : 'kg'}</View>
                  //         {
                  //           obj?.sale_mode === 0 && it?.sale_price !== it?.standard_sale_price && <View className={styles.lastBox}>¥{it?.standard_sale_price / 100}/{obj?.sale_mode === 1 ? 'm' : 'kg'}</View>
                  //         }
                  //       </View>
                  //       <View className={styles.itemMoneyOne}>¥{formatPriceDiv(it.total_sale_price)}</View>
                  //     </View>
                  //   </View>
                  // </View>

                  // {/* 第二个版本的样式 */}

                    <View className={styles.product_goods} key={inx}>
                      <View className={styles.prodct_name}>{formatHashTag(it.code, it.name)} x{obj?.sale_mode === EnumSaleMode.Bulk ? it.roll : formatMeterDiv(it.length)}{obj?.sale_mode === EnumSaleMode.Bulk ? '条' : 'm'}</View>
                      <View className={styles.product_right}>
                        {
                          (obj?.sale_mode === EnumSaleMode.Bulk && it?.sale_price !== it?.standard_sale_price) ? <View className={styles.lastBox}>¥{formatPriceDiv(it?.standard_sale_price, 100, true)}/kg</View> : null
                        }
                        <View className={styles.itemMoney}>¥{formatPriceDiv(it.sale_price, 100, true)}/{obj?.sale_mode === EnumSaleMode.Plate ? 'm' : 'kg'}</View>
                        <View className={styles.itemMoneyOne}>¥{formatPriceDiv(it.total_sale_price, 100, true)}</View>
                      </View>
                    </View>

                  )
                })
              }
            </View>
          )
        })
      }
    </>

  )
}
const GoodsItemWithMemo = memo(GoodsItem)
enum AdjustPriceAuditStatus {
  NONE = 0,
  PASS = 3,
  PENDING = 1,
  REFUSE = 2,
}
interface NotificationProps{
  salesOrderId: number
  auditStatus: AdjustPriceAuditStatus
  baseData: any
  onSuccess: () => void
  isReadjust: boolean
  saleUserId: number
}
// 服务通知
const ServicesNotification = (props: NotificationProps) => {
  const { userInfo } = useUserInfo()
  const { salesOrderId, auditStatus, baseData, onSuccess, isReadjust, saleUserId } = props
  const { fetchData: pass } = PassAdjustPriceAudit()
  const { fetchData: refuse } = RefuseAdjustPriceAudit()

  const handleRefuse = async() => {
    const res = await refuse({
      sale_order_id: salesOrderId,
    })
    if (res.success) {
      Taro.showToast({
        title: '拒绝成功',
        icon: 'success',
        duration: 2000,
      })
      onSuccess()
    }
  }
  const handlePass = async() => {
    const res = await pass({
      sale_order_id: salesOrderId,
    })
    if (res.success) {
      Taro.showToast({
        title: '审核通过',
        icon: 'success',
        duration: 2000,
      })
      onSuccess()
    }
  }

  const [showDialog, setShowDialog] = useState(false)
  const handleShowDialog = (bool) => {
    setShowDialog(bool)
  }
  // 点击分享
  const handleShare = () => {
    console.log('handleShare')
    handleShowDialog(false)
  }

  useEffect(() => {
    if (userInfo.userInfo.user_id) {
      if (auditStatus === AdjustPriceAuditStatus.PENDING && isReadjust && userInfo.userInfo.user_id === saleUserId) {
        handleShowDialog(true)
      }
    }
  }, [isReadjust, auditStatus, saleUserId, userInfo])

  const statusStyles = useMemo(() => {
    const res = {
      background: '',
      textColor: '',
      icon: null as React.ReactNode,
    }
    if (auditStatus === AdjustPriceAuditStatus.PENDING) {
      res.background = styles.pendingBackground
      res.textColor = styles.pendingName
      res.icon = <IconFont name="icon-daishenhe" size={56} color="#337fff"></IconFont>
    }
    else if (auditStatus === AdjustPriceAuditStatus.PASS) {
      res.background = styles.passBackground
      res.textColor = styles.passName
      res.icon = <IconFont name="icon-shenhetongguo" size={56} color="#03b15f"></IconFont>
    }
    else if (auditStatus === AdjustPriceAuditStatus.REFUSE) {
      res.background = styles.refuseBackground
      res.textColor = styles.refuseName
      res.icon = <IconFont name="icon-shenhejujue" size={56} color="#f64861"></IconFont>
    }
    return res
  }, [auditStatus])
  return <View className={classnames(styles.status, statusStyles.background)}>
    <View className={styles.statusLeft}>
      <View className={styles.statusTitle}>
        {statusStyles.icon}
        <Text className={classnames(styles.statusName, statusStyles.textColor)}>{baseData.adjust_price_audit_status_name}</Text>
      </View>
      <View className={styles.price}>单价调整超过 {formatPriceDiv(baseData.max_adjust_price)} 元</View>
    </View>
    <View className={styles.statusRight}>
      {
        auditStatus === AdjustPriceAuditStatus.PENDING
          ? <View className={styles.buttonBar}>
            <NormalButton customClassName={styles.refuseButton} type="primary" size="small" circle plain onClick={handleRefuse}>拒绝</NormalButton>
            <NormalButton customClassName={styles.passButton} type="primary" size="small" circle onClick={handlePass}>同意</NormalButton>
          </View>
          : <>
            <View className={styles.name}>审核人员：{baseData.adjust_price_audit_name}</View>
            <View className={styles.time}>审核时间：{formatDateTime(baseData.adjust_price_audit_time)}</View>
          </>
      }
    </View>
    <Dialog show={showDialog} onChange={handleShowDialog}>
      <View className={classnames(styles.statusDialog, statusStyles.background)}>
        <View className={styles.statusLeft}>
          <View className={styles.closeDialog} onClick={() => handleShowDialog(false)}>
            <IconFont name="icon-guanbi" size={50} color="#6b6d71"></IconFont>
          </View>
          <View className={styles.statusTitle}>
            {statusStyles.icon}
            <Text className={classnames(styles.statusName, statusStyles.textColor)}>{baseData.adjust_price_audit_status_name}</Text>
          </View>
          <View className={styles.price}>单价调整超过 {formatPriceDiv(baseData.max_adjust_price)} 元，请分享至上级</View>
        </View>
        {/* <NormalButton round type="primary" customClassName={styles.shareBtn} onClick={handleShare}>
        </NormalButton> */}
        <Button openType="share" className={styles.shareBtn} onClick={handleShare}>点击分享</Button>
      </View>
    </Dialog>
  </View>
}

const OrderDetails = () => {
  const router = useRouter()
  // useEffect(() => {
  //     getDetail()
  // }, [])

  // 收货方法,1:自提，2物流
  const [receivingStatus, setReceivingStatus] = useState(null)
  // 切换自提或者物流
  const { fetchData: selectFetch } = MpSaleOrderShipmentMode()
  const onReceivingStatus = debounce(async(e, value) => {
    if (infoObj.status === 8 || infoObj.status === 9 || infoObj.status === 4 || infoObj.status === 5 || infoObj.status === 3 || infoObj.status === 11) {
      alert.error('不允许更改')
      return false
    }
    e.stopPropagation()
    if (receivingStatus === value) {
      alert.error('不能选择相同的方式')
      return false
    }
    Taro.showLoading({
      title: '请稍等...',
      mask: true,
    })
    const res = await selectFetch({ id: Number(infoObj.id), shipment_mode: value })
    if (res.msg === 'success') {
      Taro.hideLoading()
      Taro.showToast({
        title: '成功',
        icon: 'success',
      })
      setReceivingStatus(value)
      getDetail()
    }
    else {
      if (res.data.code == 70029) {
        Taro.hideLoading()
        Taro.showToast({
          title: res.msg,
          icon: 'error',
        })
      }
      else {
        Taro.hideLoading()
        Taro.showToast({
          title: '请先去新增地址',
          icon: 'error',
        })
      }
    }
  }, 300)

  const { fetchData: infoFetch, state } = MpSaleOrder()
  // 是否有调整价格
  const isReadjust = useMemo(() => {
    return state.data.product_list?.some(item => item.product_colors?.some(item => item?.sale_price !== item?.standard_sale_price))
  }, [state])

  const [infoObj, setInfoObj] = useState<any>({})
  // 获取订单详情
  const getDetail = async() => {
    Taro.showLoading({
      title: '加载中...',
      mask: true,
    })
    const res = await infoFetch({ id: router.params.id })
    Taro.hideLoading()
    // 小程序提供的api，通知页面停止下拉刷新效果
    Taro.stopPullDownRefresh()
    orderMsg.forEach((it) => {
      if (it.leftTitle === '订单编号：') {
        it.rightTitle = res.data.order_no
      }
      if (it.leftTitle === '创建时间：') {
        it.rightTitle = formatDateTime(res.data.create_time)
      }
      if (it.leftTitle === '发货时间：') {
        it.rightTitle = formatDateTime(res.data.delivery_time)
      }
      if (it.leftTitle === '业务员：') {
        it.rightTitle = res.data.sale_user_name
      }
      if (res.data.change_time !== '') {
        if (it.leftTitle === '编辑时间：') {
          it.rightTitle = formatDateTime(res.data.change_time)
        }
      }
      else {
        if (it.leftTitle === '编辑时间：') {
          it.showFont = false
        }
      }
    })
    res.data.picUrl = res.data.delivery_appendix_url?.map((item) => {
      item = IMG_CND_Prefix + item
      return item
    })
    res.data.logistics_details?.map((item) => {
      if (item.status == '待收货') {
        item.delivery_appendix_url = res.data.delivery_appendix_url?.map((item) => {
          item = IMG_CND_Prefix + item
          return item
        })
      }
      return item
    })
    setInfoObj(res.data)
    setOrderMsg([...orderMsg])
    setReceivingStatus(res.data.shipment_mode)
  }
  // 复制功能
  const clipboardData = () => {
    Taro.setClipboardData({
      data: infoObj?.order_no || '',
      success(res) {
        Taro.showToast({
          icon: 'none',
          title: '复制成功',
        })
      },
    })
  }
  const page = Taro.getCurrentInstance().page
  if (page && page.onShareAppMessage) {
    page.onShareAppMessage = (res) => {
      console.log('useShareAppMessage', res)
      let shareTitle = `订单${infoObj.order_no}`
      if (res.from === 'button') {
        // 来自页面内转发按钮
        console.log(res.target)
        shareTitle += `，${infoObj.adjust_price_audit_status_name}`
      }
      return {
        title: shareTitle,
        path: `/pages/orderDetails/index?id=${infoObj.id}`,
      }
    }
  }

  // useEffect(() => {
  //     setReceivingStatus(receivingStatus)
  // }, [receivingStatus])
  // 订单信息文字数组
  const [orderMsg, setOrderMsg] = useState<any[]>([
    {
      leftTitle: '订单编号：',
      rightTitle: '------',
      showBtn: true,
      showFont: true,
    },
    {
      leftTitle: '创建时间：',
      rightTitle: '------',
      showFont: true,
    },
    {
      leftTitle: '发货时间：',
      rightTitle: '------',
      showFont: true,
    },
    {
      leftTitle: '业务员：',
      rightTitle: '------',
      showFont: true,
    },
    {
      leftTitle: '编辑时间：',
      rightTitle: '------',
      showFont: true,

    },
  ])

  // 备注操作
  const [showDesc, setShowDesc] = useState(false)
  const { fetchData: remarkFetch } = MpSaleOrderPut()
  const getRemark = async() => {
    const res = await remarkFetch({ remark: infoObj.remark, id: Number(router.params.id) })
    if (res.msg === 'success') {
      Taro.showToast({
        title: '成功',
        icon: 'success',
      })
      setShowDesc(false)
      getDetail()
    }
  }

  // 更多按钮查看操作
  const [showMore, setShowMore] = useState(false)

  // 刷新页面
  const refresh = useCallback(() => {
    alert.loading('刷新中')
    getDetail()
  }, [])

  const { fetchData: cancelFetch } = MpSaleOrderCancel()
  // 取消订单
  const cancle = async(e, item) => {
    e.stopPropagation()
    Taro.showModal({
      content: '确定要取消吗？',
      confirmText: '确认',
      cancelText: '取消',
      async success(res) {
        if (res.confirm) {
          Taro.showLoading({
            title: '请稍等...',
            mask: true,
          })
          const res = await cancelFetch({ id: item.id })
          if (res.msg === 'success') {
            Taro.showToast({
              title: '取消成功',
            })
            Taro.hideLoading()
            getDetail()
          }
          else {
            Taro.showToast({
              title: res.msg,
              icon: 'error',
            })
          }
        }
      },
    })
  }
  // 再次购买
  const { fetchData: buyFetch } = MpShoppingCartProductColorList()
  const nextBuy = async(e, item) => {
    e.stopPropagation()
    Taro.showLoading({
      title: '请稍等...',
      mask: true,
    })
    const arr: any = []
    item.product_list.forEach((item) => {
      item.product_colors.forEach((it) => {
        arr.push({
          length: it.length,
          roll: it.roll,
          product_color_id: it.id,
        })
      })
    })
    const query = {
      purchaser_id: item.purchaser_id,
      sale_mode: item.sale_mode,
      color_list: arr,
    }
    const res = await buyFetch(query)
    if (res.msg === 'success') {
      Taro.showToast({
        title: '加入购物车成功!',
      })
      Taro.hideLoading()
      getDetail()
    }
    else {
      Taro.showToast({
        title: res.msg,
        icon: 'error',
      })
    }
  }

  // 扫码支付
  const [showSide, setShowSide] = useState(true)
  const [title, setTitle] = useState('')
  const [picUrl, setPicUrl] = useState('')

  // 显示支付
  const [showPay, setShowPay] = useState(false)
  // 去支付逻辑
  const { fetchData: infoOneFetch } = OrderPaymentOrderPaymentMethodInfo()
  const { fetchData: infoTwoFetch } = OrderPaymentPreCollectOrderOrderPaymentMethodInfo()
  const [payList, setPayList] = useState<any[]>(paywayList)
  const toPay = async(e, item) => {
    e.stopPropagation()
    console.log('toPay', item)
    if (item.status !== 10) {
      const res = await infoOneFetch({ id: item.should_collect_order_id })
      setmd5Key(res.data.md5_key)
      // 待发货、待收货、待自提、已收货
      const filter = payList.filter((it) => {
        // 1. 待发货、待收货、待自提、已收货   隐藏货到付款 账期
        // 2. 散剪、剪板  待付款状态         隐藏货到付款 账期
        if ([3, 8, 13, 9].includes(item.status) || ([7].includes(item.status) && [EnumSaleMode.BulkCut, EnumSaleMode.Plate].includes(item.sale_mode))) {
          return ![5, 3].includes(it.id)
        }
        else {
          return true
        }
      })
      console.log('filter', filter)
      filter.map((item) => {
        if (item.id === 3) {
          item.name = `${res.data.account_period}天账期`
          item.fonts = `可用额度${formatPriceDiv(
            res.data.account_period_credit_available_line,
          ).toLocaleString()}`
        }
        if (item.id === 2) {
          item.fonts = `可用额度${formatPriceDiv(
            res.data.advance_deposit_balance,
          ).toLocaleString()}`
        }
        return item
      })
      setPayList([...filter])
      if (item.is_shipper_picks_up) {
        const obj = filter.filter((item) => {
          return item.id === 6
        })
        console.log(obj, '456456')
        if (obj.length === 0) {
          filter.unshift({
            id: 6,
            iconfont: 'icon-huozhuziti',
            name: '货主自提',
            color: '#ffffff',
            fonts: '',
            money: '',
            isCheck: false,
          })
          setPayList([...filter])
        }
      }
    }
    else {
      const res = await infoTwoFetch({ id: item.pre_collect_order_id })
      setmd5Key(res.data.md5_key)
      const arr: any = []
      arr.push(
        {
          id: 2,
          iconfont: 'icon-yufukuan1',
          name: '预存款',
          fonts: `可用额度${formatPriceDiv(
            res.data.advance_deposit_balance,
          ).toLocaleString()}`,
          money: '',
          isCheck: false,
        },
        {
          iconfont: 'icon-yue',
          name: '线下汇款',
        },
        {
          iconfont: 'icon-saomiao',
          name: '扫码支付',
          color: '#ffffff',
        },
      )
      if (item.is_shipper_picks_up) {
        const obj = arr.filter((item) => {
          return item.id === 6
        })
        if (obj.length === 0) {
          arr.unshift({
            id: 6,
            iconfont: 'icon-huozhuziti',
            name: '货主自提',
            fonts: '',
            money: '',
            isCheck: false,
            color: '#ffffff',
          })
        }
      }
      setPayList([...arr])
    }
    setShowSide(true)
    setTitle('待支付款项')
    setShowPay(true)
  }

  useDidShow(() => {
    getDetail()
  })
  // 页面下拉刷新
  usePullDownRefresh(() => {
    console.log('usePullDownRefresh')
    getDetail()
  })

  const [md5Key, setmd5Key] = useState('')

  const { fetchData: payFetch } = GetPayCode()
  const handScanpay = async() => {
    const list: any = []
    infoObj.product_list.forEach((item) => {
      item.product_colors.forEach((it) => {
        list.push({
          product_code: item.code,
          product_name: item.name,
          product_color_code: formatRemoveHashTag(it.code),
          product_color_name: it.name,
          num: it.roll.toString(),
          weight: formatWeightDiv(it.actual_weight).toString(),
          sale_price: (it.sale_price / 100).toString(),
          total_price:
                        it.total_sale_price !== 0
                          ? (it.total_sale_price / 100).toString()
                          : (it.estimate_amount / 100).toString(),
          length: (it.length / 100).toString(),
          weight_error: formatWeightDiv(it.weight_error).toString(),
        })
      })
    })
    const query = {
      list,
      title: '面料销售电子确认单',
      show_qrcode: true,
      show_barcode: true,
      order_type: infoObj.sale_mode_name,
      shipment_mode: infoObj.shipment_mode_name,
      company: infoObj.title_purchaser_name,
      sale_user: infoObj.sale_user_name,
      order_created_time: formatDateTime(infoObj.create_time),
      order_no: infoObj.order_no,
      target_user_name: infoObj.target_user_name,
      target_address: infoObj.address_detail,
      target_description: infoObj.remark,
      pay_account: infoObj.transfer_remittance_account,
      bank_account_name: infoObj.account_name,
      bank_name: infoObj.bank_of_deposit,
      pay_type: infoObj.settle_mode_name,
      client: infoObj.purchaser_name,
      phone: infoObj.target_user_phone,
      order_total_length: (infoObj.total_number / 100).toString(),
      order_total_price: (
        infoObj.bill_total_sale_price / 100
      ).toString(),
      total_weight_error_discount: (
        infoObj.total_weight_error_discount / 100
      ).toString(),
      order_total_num: infoObj.total_number.toString(),
      qrcode: `${PAY_H5_CODE_URL}?key=${md5Key}`,
      order_total_weight: (infoObj.total_weight / 1000).toString(),
      estimate_amount: (infoObj.estimate_amount / 100).toString(),
      total_sale_price: (infoObj.total_sale_price / 100).toString(),
      actual_amount: (infoObj.actual_amount / 100).toString(),
      wait_pay_amount: (infoObj.wait_pay_amount / 100).toString(),
      order_total_weight_error: (
        infoObj.total_weight_error / 1000
      ).toString(),
      show_sale_price: infoObj?.sale_mode === 0 && infoObj?.is_display_price ? true : !!((infoObj?.sale_mode === 1 || infoObj?.sale_mode === 2)),
      show_total_price: infoObj?.sale_mode === 0 && infoObj?.is_display_price ? true : !!((infoObj?.sale_mode === 1 || infoObj?.sale_mode === 2)),
      show_estimate_amount: infoObj?.sale_mode === 0 && infoObj?.is_display_price ? true : !!((infoObj?.sale_mode === 1 || infoObj?.sale_mode === 2)),
      show_total_sale_price: infoObj?.sale_mode === 0 && infoObj?.is_display_price ? true : !!((infoObj?.sale_mode === 1 || infoObj?.sale_mode === 2)),
      show_total_weight_error_discount: infoObj?.sale_mode === 0 && infoObj?.is_display_price ? true : !!((infoObj?.sale_mode === 1 || infoObj?.sale_mode === 2)),
      show_actual_amount: infoObj?.sale_mode === 0 && infoObj?.is_display_price ? true : !!((infoObj?.sale_mode === 1 || infoObj?.sale_mode === 2)),
      show_wait_pay_amount: infoObj?.sale_mode === 0 && infoObj?.is_display_price ? true : !!((infoObj?.sale_mode === 1 || infoObj?.sale_mode === 2)),
      show_tips: true,
      tips: `请核对本单后验收， <b>如发现质量问题，请于收到货之日起3天内与平台客服联系协商解决，</b>逾期不作处理即表示购方默认对货物无异议；<b>购方确认无任何问题方可裁剪/加工，一经裁剪，缩水等工艺，平台概不负责；</b>
      看布购货，请先试缩水，并注意分缸裁布！如需撞色拼接，请先试色牢度。非质量问题，恕不退换，谢谢合作！`,
    }
    const res = await payFetch(query)
    if (res.data) {
      console.log(res.data.base64)
      setShowSide(false)
      setTitle('查看销售码单')
      setPicUrl(res.data.base64)
    }
  }

  // 确认交易
  const { fetchData: payOneFetch } = OrderPaymentOrderPaymentSubmission()
  const { fetchData: payTwoFetch } = OrderPaymentPreCollectOrderOrderPaymentSubmission()
  const handsurePay = (obj) => {
    let arr: any = []
    // if (obj.status !== 10) {
    arr = payList.filter((item) => {
      return item.checked
    })
    if (!arr.length) {
      Taro.showToast({
        title: '请选择后再提交',
        icon: 'error',
      })
      return false
    }

    Taro.showModal({
      content: '确定交易吗？',
      confirmText: '确认',
      cancelText: '取消',
      async success(res) {
        if (res.confirm) {
          Taro.showLoading({
            title: '请稍等...',
            mask: true,
          })
          const restult = await (obj.status !== 10 ? payOneFetch({ id: Number(obj.should_collect_order_id), payment_method: Number(arr[0]?.id) }) : payTwoFetch({ id: Number(obj.pre_collect_order_id), payment_method: Number(arr[0]?.id) }))
          if (restult?.msg === 'success') {
            Taro.showToast({
              title: '交易成功',
            })
            Taro.hideLoading()
            setShowPay(false)
            getDetail()
          }
          else {
            Taro.hideLoading()
            Taro.showToast({
              title: restult?.msg,
              icon: 'error',
            })
          }
        }
      },
    })

    // }
  }

  // 显示线下汇款
  const [showOffline, setShowOffline] = useState(false)
  // 选择地址
  const handSelect = (obj) => {
    if (receivingStatus === 1 || (infoObj.status === 8 || infoObj.status === 9 || infoObj.status === 4 || infoObj.status === 5 || infoObj.status === 11 || infoObj.status === 3)) {
      alert.error('不允许更改')
      return false
    }
    Taro.navigateTo({
      url: `/pages/addressManager/index?orderId=${obj.id}&purchaser_id=${obj.purchaser_id}`,
    })
  }

  // 是否显示按钮
  const showBtn = useMemo(() => {
    if ((infoObj.status === 8 || infoObj.status === 9 || infoObj.status === 4 || infoObj.status === 5 || infoObj.status === 11 || infoObj.status === 3)) {
      return false
    }
    else {
      return true
    }
  }, [infoObj])

  const showWhatFont = useMemo(() => {
    if (infoObj.shipment_mode === 1) {
      return '自提商品'
    }
    else {
      return '物流'
    }
  }, [infoObj])

  // 申请退货
  const handApplyGood = () => {
    if (infoObj.av_return_product.length == 0) {
      return alert.error('暂无货物退')
    }
    else {
      Taro.navigateTo({
        url: `/pages/applyGoods/index?orderId=${infoObj.id}`,
      })
      setShowMore(false)
    }
  }

  // 申请退款
  const handApplyMoney = () => {
    // 三种类型的   待收货，已收货后申请退货退款，需要选择质量/非质量问题
    if (infoObj?.status == 8 || infoObj?.status == 9) {
      Taro.navigateTo({
        url: `/pages/applyGoods/index?orderId=${infoObj.id}`,
      })
    }
    else {
      Taro.navigateTo({
        url: `/pages/applyMoney/index?orderId=${infoObj.id}`,
      })
    }
    setShowMore(false)
  }

  // 确认收货
  const { fetchData: receveFetch } = MpSaleOrderReceive()
  const handSureGoods = async() => {
    Taro.showModal({
      content: '确认收货吗？',
      confirmText: '确认',
      cancelText: '取消',
      async success(res) {
        if (res.confirm) {
          Taro.showLoading({
            title: '请稍等...',
            mask: true,
          })
          const res = await receveFetch({ sale_order_id: Number(infoObj.id) })
          if (res?.msg === 'success') {
            Taro.showToast({
              title: '成功',
            })
            Taro.hideLoading()
            setShowMore(false)
            getDetail()
          }
          else {
            Taro.hideLoading()
            Taro.showToast({
              title: res?.msg,
              icon: 'error',
            })
          }
        }
      },
    })
  }

  const onChange = (e) => {
    setInfoObj(val => ({ ...val, remark: e }))
  }
  // 选择支付方式
  const clickItem = (item) => {
    if (item.name === '扫码支付') { handScanpay() }
    if (item.name === '线下汇款') { setShowOffline(true) }
    payList.map((it) => {
      if (item.id === it.id) {
        it.checked = true
      }
      else {
        it.checked = false
      }
      return it
    })
    setPayList([...payList])
  }
  useEffect(() => {
    setInfoObj(infoObj)
  }, [infoObj])
  const showRemarkFont = useMemo(() => {
    if (infoObj.status === 10 || infoObj.status == 0 || infoObj.status == 1 || infoObj.status == 2 || infoObj.status == 7) {
      return `${'填写/修改备注'} >`
    }
    else {
      return ''
    }
  }, [infoObj])

  const BottomBtnsRef = useRef<any>()
  const [showOther, setshowOther] = useState(false)
  useMemo(() => {
    Taro.nextTick(() => {
      if (BottomBtnsRef.current?.btnList.length > 3) {
        setshowOther(true)
        return true
      }
      else {
        setshowOther(false)
        return false
      }
    })
  }, [infoObj])
  // 待接单、配布中、已配布状态时，叫预估金额，其他状态叫合计金额。
  const payFont = useMemo(() => {
    if (infoObj?.status === 0 || infoObj?.status === 1 || infoObj?.status === 2) {
      return '预估金额'
    }
    else {
      return '合计金额'
    }
  }, [infoObj])

  const [showCodeList, setshowCodeList] = useState(false)
  // 展示码单
  const handShowCodeList = () => {
    setshowCodeList(true)
  }

  // 修改订单
  const handEdit = () => {
    Taro.navigateTo({
      url: `/pages/orderEdit/index?orderId=${infoObj.id}`,
    })
  }

  const onSuccess = () => {
    getDetail()
  }

  return (
    <View className={styles.mainBox}>
      <View style={infoObj.adjust_price_audit_status !== AdjustPriceAuditStatus.NONE ? { position: 'relative', paddingTop: '75px' } : {}}>
        {
          infoObj.adjust_price_audit_status !== AdjustPriceAuditStatus.NONE && <ServicesNotification saleUserId={infoObj.sale_user_id} isReadjust={isReadjust} salesOrderId={infoObj.id} auditStatus={infoObj.adjust_price_audit_status} baseData={infoObj} onSuccess={onSuccess}></ServicesNotification>
        }
        {(infoObj?.status != 10 && <OrderState picUrl={infoObj?.picUrl} orderInfo={infoObj} />)}
        {
          infoObj.status === 10 && <AdvanceOrderState orderInfo={infoObj} onRefresh={() => refresh()} />
        }
      </View>
      <AddressDetailBox
        showBtn={showBtn}
        showWhatFont={showWhatFont}
        navSelect={obj => handSelect(obj)}
        obj={infoObj}
        receivingStatus={receivingStatus}
        onReceivingStatus={(e, value) => onReceivingStatus(e, value)}
      ></AddressDetailBox>
      <DefaultBox
        showMode
        title="客户信息"
        modeName={infoObj.sale_mode_name}
      >
        <View className={styles.pussBox}>
          <View className={styles.pussName}>{infoObj.purchaser_name}</View>
          <View className={styles.pussName}>
            {
              infoObj?.platform_source !== 1 && <Tag type="primary" size="normal" circle customClassName={styles.platform_name} plain>
                {infoObj?.platform_source_name || '暂无'}
              </Tag>
            }
          </View>
          <View className={styles.pussPhone}>{infoObj.purchaser_phone}</View>
        </View>
      </DefaultBox>
      <View className={styles.total}> {infoObj.total_fabrics} 种面料，{infoObj.total_colors} 个颜色，共 {infoObj.sale_mode === 0 ? infoObj.total_number : infoObj.total_number / 100} {infoObj.sale_mode === 0 ? '条' : 'm'}</View>
      <View className={styles.productBox}>
        <GoodsItem list={infoObj?.product_list} obj={infoObj}></GoodsItem>
        <View className={styles.flexMoney}>
          <View className={styles.flexTotalBox}>
            <View className={styles.totalFont}>{payFont}</View>
          </View>
          <View className={styles.shoudPay}>¥{formatPriceDiv(infoObj.bill_total_sale_price, 100, true)}</View>
        </View>
        <View className={styles.flexMoney}>
          <View className={styles.flexTotalBox}>
            <View className={styles.totalFont}>实付金额</View>
          </View>
          <View className={styles.shoudPay}>¥{formatPriceDiv(infoObj.actual_amount, 100, true)}</View>
        </View>
        {
          infoObj?.wait_pay_amount < 0 && <View className={styles.flexMoney}>
            <View className={styles.flexTotalBox}>
              <View className={styles.totalFont}>{infoObj?.wait_pay_amount?.toString().indexOf('-') !== -1 ? '退款金额' : '待付金额'}</View>
            </View>
            <View className={styles.shoudPay}>¥{formatPriceDiv(infoObj.refund_amount, 100, true)}</View>
          </View>
        }
        {
          infoObj?.wait_pay_amount > 0 && <View className={styles.flexMoney}>
            <View className={styles.flexTotalBox}>
              <View className={styles.totalFont}>{infoObj?.wait_pay_amount?.toString().indexOf('-') !== -1 ? '退款金额' : '待付金额'}</View>
            </View>
            <View className={styles.shoudPay}>¥{formatPriceDiv(infoObj.wait_pay_amount, 100, true)}</View>
          </View>
        }
      </View>
      <DefaultBox title="订单信息">
        {
          orderMsg.map((item, index) => {
            return (

              item.showFont && <View className={styles.detailBox} key={index}>
                <View className={styles.detailFont}>
                  {item.leftTitle}
                </View>
                <View className={styles.detailRightFlex}>
                  <View className={styles.detailRight}>{item.rightTitle}</View>
                  {item.showBtn && <View className={styles.detailBtn} onClick={() => clipboardData()}>复制</View>}
                </View>

              </View>
            )
          })
        }

      </DefaultBox>
      <DefaultBox title="备注信息" showMode modeName={showRemarkFont} clickNode={() => setShowDesc(showRemarkFont != '')}>
        <View className={styles.remarkFont}>{infoObj.remark === '' ? '暂无' : infoObj.remark}</View>
      </DefaultBox>

      <Popup show={showDesc} title="填写/编辑备注" showTitle onClose={() => setShowDesc(false)}>
        <View style={{ margin: '24rpx' }}>
          <Remark
            //  onSave={(e) => getRemark(e)}
            onChange={e => onChange(e)}
            defaultValue={infoObj.remark}
          />
          <View className={styles.order_save_address} onClick={() => getRemark()}>保存</View>
        </View>

      </Popup>
      <View className={styles.safeBottom}></View>
      <View className={styles.bottomBox}>
        {
          showOther
                    && <>
                      {
                        !showMore && <View className={styles.moreFontBox}> <View className={styles.moreFont} onClick={() => setShowMore(true)}>更多</View></View>
                      }
                      {
                        showMore && <View className={styles.moreFontBox}>  <View className={styles.moreFont} onClick={() => setShowMore(false)}>关闭</View></View>
                      }
                      {
                        showMore && <View className={styles.posssBox}>
                          <BottomApply
                            obj={infoObj}
                            goodsObj={infoObj}
                            handApplyGoods={() => handApplyGood?.()}
                            handApplyMoney={() => handApplyMoney?.()}
                            nextBuy={e => nextBuy?.(e, infoObj)}
                            handSureGoods={() => handSureGoods?.()}
                            handShowCodeList={() => handShowCodeList?.()}
                            cancle={e => cancle?.(e, infoObj)}
                          ></BottomApply>
                        </View>
                      }
                    </>
        }

        <BottomBtns
          ref={BottomBtnsRef}
          showDetail
          goodsObj={infoObj}
          obj={infoObj}
          showTuiGoods
          cancle={e => cancle?.(e, infoObj)}
          nextBuy={e => nextBuy?.(e, infoObj)}
          toPay={e => toPay?.(e, infoObj)}
          handShowCodeList={() => handShowCodeList?.()}
          handSureGoods={() => handSureGoods?.()}
          handApplyGoods={() => handApplyGood?.()}
          handApplyMoney={() => handApplyMoney?.()}
          handEdit={() => handEdit?.()}
        ></BottomBtns>
      </View>
      <PayPopup
        list={payList}
        obj={infoObj}
        showPopup={showPay}
        popupClose={() => setShowPay(false)}
        clickItem={infoObj => clickItem(infoObj)}
        handsurePay={infoObj => handsurePay(infoObj)}
        showSide={showSide}
        title={title}
        picUrl={picUrl}
      ></PayPopup>
      <OfflinePay showKong={false} show={showOffline} onClose={() => setShowOffline(false)} offlineInfo={infoObj}></OfflinePay>
      <SaleCodeList obj={infoObj} showPopup={showCodeList} popupClose={() => setshowCodeList(false)}></SaleCodeList>
    </View>
  )
}
export default OrderDetails
