import { Text, View } from '@tarojs/components'
import classnames from 'classnames'
import { useMemo } from 'react'
import StatusLine, { IStatusType } from '../statusLine'
import styles from './index.module.scss'
import LayoutBlock from '@/components/layoutBlock'
import Divider from '@/components/Divider'
import Tag from '@/components/tag'
import IconFont from '@/components/iconfont/iconfont'
import { goLink } from '@/common/common'

const defaultStatusLine = [
  {
    id: 1,
    order_warning_process: 1,
    colorClassName: IStatusType.WAITING,
    type: IStatusType.WAITING,
    typeName: '开始',
  },
  {
    id: 2,
    order_warning_process: 2,
    colorClassName: IStatusType.WAITING,
    type: IStatusType.WAITING,
    typeName: '接单',
  },
  {
    id: 3,
    order_warning_process: 3,
    colorClassName: IStatusType.WAITING,
    type: IStatusType.WAITING,
    typeName: '配布',
  },
  {
    id: 4,
    children: [
      {
        id: 5,
        order_warning_process: 4,
        colorClassName: IStatusType.WAITING,
        type: IStatusType.WAITING,
        typeName: '提货',
      },
      {
        id: 6,
        order_warning_process: 5,
        colorClassName: IStatusType.WAITING,
        type: IStatusType.WAITING,
        typeName: '收款',
      },
    ],
  },
  {
    id: 7,
    order_warning_process: 6,
    colorClassName: IStatusType.WAITING,
    type: IStatusType.WAITING,
    typeName: '出仓',
  },
  {
    id: 8,
    order_warning_process: 7,
    colorClassName: IStatusType.WAITING,
    type: IStatusType.WAITING,
    typeName: '收货',
  },
]

interface IProps {
  data: any
}

const typeStyles = {
  已完成: styles.success,
  有异常: styles.pending,
  超时完成: styles.fail,
  已取消: styles.cancel,
}

const OrderItem = (props: IProps) => {
  const { data } = props
  const handleClickDetail = () => {
    goLink('/pages/orderWarningAnalysis/orderWarningAnalysisDetail/index', {
      id: data.sale_order_id,
    })
  }

  const dispenseStatus = (item: any, baseData: any) => {
    if (baseData.handle_status_name === '已取消') {
      return IStatusType.CANCAL
    }
    // 已处理 未超时  就是已完成
    if (item.is_handle && !item.is_timeout) {
      return IStatusType.SUCCESS
    }
    else if (item.is_handle && item.is_timeout) { // 超时 已处理  就是超时完成
      return IStatusType.FAIL
    }
    else if (!item.is_handle && item.is_timeout) { // 超时 未处理  就是进行中异常
      return IStatusType.PENDING
    }
    else {
      return IStatusType.WAITING
    }
  }

  const statusLine = useMemo(() => {
    const temp = JSON.parse(JSON.stringify(defaultStatusLine))
    return temp.map((item) => {
      if (item.children && item.children.length > 0) {
        item.children = item.children.map((subItem) => {
          let index = data?.order_process?.findIndex(i => i.order_warning_process === subItem.order_warning_process)
          index = index == null ? -1 : index
          if (index !== -1) {
            const target = data?.order_process[index]
            return {
              id: subItem.id,
              order_warning_process: target.order_warning_process,
              colorClassName: dispenseStatus(target, data),
              type: dispenseStatus(target, data),
              typeName: target.order_warning_process_name,
            }
          }
          else {
            return subItem
          }
        })
        return item
      }
      else {
        let index = data?.order_process?.findIndex(i => i.order_warning_process === item.order_warning_process)
        index = index == null ? -1 : index
        if (index !== -1) {
          const target = data?.order_process[index]
          return {
            id: item.id,
            order_warning_process: target.order_warning_process,
            colorClassName: dispenseStatus(target, data),
            type: dispenseStatus(target, data),
            typeName: target.order_warning_process_name,
          }
        }
        else {
          return item
        }
      }
    })
  }, [data])

  const colorGray = () => {
    return data?.handle_status_name === '已取消' ? styles.cancelColor : null
  }

  return <LayoutBlock circle customClassName={data?.handle_status_name === '已取消' ? styles.gray : ''} flexDirection="col" customStyle={{ padding: '20rpx 32rpx' }} onClick={handleClickDetail}>
    <View className="flex-row justify-between ">
      <View className="flex-row items-center">
        <Tag circle customClassName={classnames(styles.tag, typeStyles[data?.handle_status_name])} type="primary" size="normal">{data?.handle_status_name}</Tag>
        <View className={classnames(styles.title, 'flex-1', colorGray())}>单号：{data?.sale_order_no}</View>
      </View>
      <View className={classnames(styles.status, colorGray())}>{data?.handle_status_name === '已取消' ? '取消' : data?.order_process?.[data?.order_process.length - 1]?.order_warning_process_name}</View>
    </View>
    <Divider direction="horizontal" customStyles={{ margin: '20rpx 0 10rpx 0 ' }}></Divider>
    <View className={classnames('flex-row', 'items-center', 'justify-between', styles.totalSummary)}>
      <View className="flex-row items-center">
        <View className={styles.name}>{data?.sale_user_name}</View>
        <View className={styles.number}>{data?.roll_or_length}</View>
        <View className={styles.address}>{data?.address}</View>
      </View>
      <IconFont name="icon-chakanquanbukehu" size={38} color="#5f5f5f"></IconFont>
    </View>
    <StatusLine line={statusLine} />
  </LayoutBlock>
}
export default OrderItem
