import type { CommonEvent } from '@tarojs/components'
import { Input, Text, View } from '@tarojs/components'
import Taro, { useDidShow, usePullDownRefresh, useRouter } from '@tarojs/taro'
import Big from 'big.js'
import type { ReactNode } from 'react'
import React, { memo, useCallback, useEffect, useMemo, useRef, useState } from 'react'
import classnames from 'classnames'
import AddressDetailBox from '../orderDetails/components/addressDetailBox'
import Remark from '../orderDetails/components//remark'
import styles from './index.module.scss'
import Popup from '@/components/popup'
import { debounce } from '@/common/util'
import { UseSubscriptionMessage } from '@/use/useCommon'
import {
  MpSaleOrderPost,
  MpSaleOrderPreview,
  SaleOrderPreViewBuyNow,
  SaleOrderSubmitBuyNow,
} from '@/api/order'
import { alert } from '@/common/common'
import { formatDateTime, formatMeterDiv, formatPriceDiv, formatPriceMul, formatRemoveHashTag, formatWeightDiv } from '@/common/format'
import IconFont from '@/components/iconfont/iconfont'
import { MpPurchaserAddressList } from '@/api/addressList'
import LabAndImg from '@/components/LabAndImg'
import { EnumSaleMode } from '@/common/Enumerate'
import Divider from '@/components/Divider'
import LayoutBlock from '@/components/layoutBlock'
import IconText from '@/components/iconText'
import Dialog from '@/components/Dialog'
import InputX from '@/components/InputX'

interface ExtendEvent {
  target: {
    value: string | number
  }
}

// 卡片盒子元素
interface Obs {
  title?: string
  modeName?: string
  showMode?: boolean
  children?: ReactNode
  clickNode?: () => void
}

const DefaultBox = (props: Obs) => {
  const {
    title = '标题',
    modeName = '大货',
    showMode = false,
    children,
    clickNode,
  } = props

  return (
    <LayoutBlock circle customStyle={{ marginTop: '24rpx' }}>
      <View className={styles.titleBox}>
        <View className={styles.title}>{title}</View>
        {
          showMode && <View className={styles.modeName} onClick={() => clickNode?.()}>{modeName}</View>
        }
      </View>
      <View className={styles.modeLine}></View>
      {children}
    </LayoutBlock>
  )
}
const DefaultBoxWithMemo = memo(DefaultBox)

// 产品商品元素
interface PropGoods {
  list: any[]
  obj: {
    sale_mode?: number | string
  }
  updateData: (data: Record<string, any>) => void
}
const GoodsItem = (props: PropGoods) => {
  const { list = [], obj = {}, updateData } = props

  const [goodsList, setGoodsList] = useState(list)

  useEffect(() => {
    setGoodsList(list)
  }, [list])

  const labAndImgObj = useCallback((item) => {
    return { lab: item.lab, rgb: item.rgb, texture_url: item.texture_url }
  }, [])

  // 长度为2 单价调整，长度为1 批量调整
  const editPayload = useRef<number[]>([])

  // 批量调整
  const handleClickBulkEdit = (parentId: number) => {
    editPayload.current = [parentId]
    setShowBulkPopup(true)
  }

  // 单价调整
  const handleEdit = (subId: number, parentId: number) => {
    editPayload.current = [subId, parentId]
    setShowPopup(true)
  }

  const [showBulkPopup, setShowBulkPopup] = useState(false)
  const handleBulkPopupChange = (bool) => {
    setShowBulkPopup(bool)
  }
  const [showPopup, setShowPopup] = useState(false)
  const handleChange = (bool) => {
    setShowPopup(bool)
  }

  const handleCancel = () => {
    setShowPopup(false)
    setShowBulkPopup(false)
  }
  // 单价调整点击确认
  const handleConfirm = () => {
    if (errorMsg) { return }
    const res = list.map((item) => {
      if (item.id === editPayload.current[1]) {
        item.product_colors = item.product_colors.map((it) => {
          if (it.id === editPayload.current[0]) {
            it.sale_price = Big(it.origin_price).add(formatPriceMul(value))
            if (obj?.sale_mode === EnumSaleMode.Bulk) {
              // 计算金额
              it.estimate_amount = formatPriceMul(Number(formatPriceDiv(it.sale_price)) * formatWeightDiv(it.estimate_weight) * it.roll)
            }
            else if (obj?.sale_mode === EnumSaleMode.Plate) {
              // 剪板
              it.estimate_amount = formatPriceMul(Number(formatPriceDiv(it.sale_price)) * formatMeterDiv(it.length))
            }
            else {
              // 散剪
              it.estimate_amount = formatPriceMul(Number(formatPriceDiv(it.sale_price)) * formatMeterDiv(it.length) / formatMeterDiv(it.length_to_weight_rate)).toFixed(0)
              console.log('estimate_amount', it.estimate_amount, formatPriceDiv(it.estimate_amount, 100, true))
            }
          }
          return it
        })
      }
      return item
    })
    setGoodsList(res)
    handleCancel()
    updateData({
      product_list: res,
      // 计算总金额
      estimate_amount: res.reduce((acc, cur) => acc + cur.product_colors.reduce((a, c) => a + c.estimate_amount, 0), 0),
    })
  }

  // 批量调整点击确认
  const handleBulkConfirm = () => {
    if (errorMsg) { return }
    const res = list.map((item) => {
      if (item.id === editPayload.current[0]) {
        item.product_colors = item.product_colors.map((it) => {
          it.sale_price = Big(it.origin_price).add(formatPriceMul(value))
          if (obj?.sale_mode === EnumSaleMode.Bulk) {
            // 计算金额
            it.estimate_amount = formatPriceMul(Number(formatPriceDiv(it.sale_price)) * formatWeightDiv(it.estimate_weight) * it.roll)
          }
          else if (obj?.sale_mode === EnumSaleMode.Plate) {
            // 剪板
            it.estimate_amount = formatPriceMul(Number(formatPriceDiv(it.sale_price)) * formatMeterDiv(it.length))
          }
          else {
            // 散剪
            it.estimate_amount = formatPriceMul(Number(formatPriceDiv(it.sale_price)) * formatMeterDiv(it.length) / formatMeterDiv(it.length_to_weight_rate))
          }
          return it
        })
      }
      return item
    })
    setGoodsList(res)
    handleCancel()
    updateData({
      product_list: res,
      // 计算总金额
      estimate_amount: res.reduce((acc, cur) => acc + cur.product_colors.reduce((a, c) => a + c.estimate_amount, 0), 0),
    })
  }
  // 批量调整
  const defaultValue = '-1.5'
  // 单价调整
  const [value, setValue] = useState(defaultValue)

  const handleInput = (e: CommonEvent & ExtendEvent) => {
    const res = e.detail.value
    setValue(res)
    return res
  }

  const errorMsg = useMemo(() => {
    let msg = ''
    console.log('errorMsg', value)
    if (/[a-zA-Z]/.test(value) || Number.isNaN(Number(value))) {
      msg = '请填写数字'
    }
    else if (Number(value) < -3) {
      msg = '不能小于-3'
    }
    else {
      msg = ''
    }
    return msg
  }, [value])

  return (
    <View>
      {
        goodsList.map((item, index) => {
          return (
            <LayoutBlock circle key={index} customClassName={index === list.length - 1 ? styles.layoutBlock : ''}>
              <View className={styles.goodsProduct}>
                <View className={styles.goodsTitle}>{formatRemoveHashTag(item.code)}# {item.name}</View>
                <View className={styles.goodsEditIcon} onClick={() => handleClickBulkEdit(item.id)}>
                  <IconText iconName="icon-bianji1" iconSize={30} svg color="#3d85ff" text="批量修改" textCustomStyle={{ color: '#3d85ff' }}></IconText>
                </View>
              </View>
              <Divider direction="horizontal" customStyles={{ marginTop: '24rpx', marginBottom: '32rpx' }}></Divider>
              {
                item.product_colors.map((it, inx) => {
                  return (
                    <View className={styles.itemGoods} key={inx}>
                      <View className={styles.itemPic}>
                        <LabAndImg value={labAndImgObj(it)} />
                      </View>
                      <View className={styles.itemRight}>
                        <View>
                          <View className={styles.item_right_top}>
                            <View className={styles.itemName}>{formatRemoveHashTag(it.code)}# {it.name}</View>
                            <View className={styles.itemNums}>x{obj?.sale_mode === EnumSaleMode.Bulk ? it.roll : formatMeterDiv(it.length)}{obj?.sale_mode === 0 ? '条' : '米'}</View>
                          </View>
                          <View className={styles.item_right_Bottom}>
                            <View className={styles.flexBox}>
                              <View className={styles.itemMoney}>¥{formatPriceDiv(it.sale_price, 100, true)}/{obj?.sale_mode === EnumSaleMode.Plate ? 'm' : 'kg'}</View>
                              {
                                (obj?.sale_mode === EnumSaleMode.Bulk && it?.sale_price !== it?.standard_price)
                                  ? <View className={styles.lastBox}>
                                    ¥{formatPriceDiv(it?.standard_price, 100, true)}/kg
                                  </View>
                                  : null
                              }
                              {
                                (obj?.sale_mode === EnumSaleMode.Plate && it?.sale_price !== it?.standard_price)
                                  ? <View className={styles.lastBox}>
                                    ¥{formatPriceDiv(it?.standard_price, 100, true)}/m
                                  </View>
                                  : null
                              }
                              {
                                (obj?.sale_mode === EnumSaleMode.BulkCut && it?.sale_price !== it?.standard_price)
                                  ? <View className={styles.lastBox}>
                                    ¥{formatPriceDiv(it?.standard_price, 100, true)}/kg
                                  </View>
                                  : null
                              }
                              <View onClick={() => handleEdit(it.id, item.id)}>
                                <IconFont name="icon-bianji1" color="#3d85ff"></IconFont>
                              </View>
                            </View>
                            <View className={styles.itemMoneyOne}>¥{formatPriceDiv(it.estimate_amount)}</View>
                          </View>
                        </View>
                        <Divider direction="horizontal" customStyles={{ marginTop: '20rpx', marginBottom: '0' }}></Divider>
                      </View>
                    </View>
                  )
                })
              }
            </LayoutBlock>
          )
        })
      }
      <Dialog zIndex={999} show={showBulkPopup} onChange={handleBulkPopupChange}>
        <View className={styles.modal}>
          <View className={styles.modalTitle}>批量调整</View>
          <View className={styles.modalContainer}>
            <View className={styles.inputBar}>
              <InputX customInputClassName={styles.input} value={value} onInput={handleInput} placeholder="请输入调价价格"></InputX>
            </View>
            {errorMsg && <Text className={styles.errorMsg}>{errorMsg}</Text>}
            <View className={styles.tips}>批量调价是在标准报价基础上调整，增加价格则输入正数，减少则输入负数</View>
          </View>
          <Divider direction="horizontal" customStyles={{ margin: '0', opacity: '0.7', transform: 'translateY(1px) scaleY(0.6)' }}></Divider>
          <View className={styles.modalButton}>
            <View className={styles['modalButton--cancel']} onClick={handleCancel}>取消</View>
            <Divider direction="vertical" customStyles={{ margin: '0', height: '100rpx', opacity: '0.7', transform: 'scaleX(0.6)' }}></Divider>
            <View className={classnames(styles['modalButton--confirm'], errorMsg && styles.disabled)} onClick={handleBulkConfirm}>确认</View>
          </View>
        </View>
      </Dialog>
      <Dialog zIndex={999} show={showPopup} onChange={handleChange}>
        <View className={styles.modal}>
          <View className={styles.modalTitle}>单价调整</View>
          <View className={styles.modalContainer}>
            <View className={styles.inputBar}>
              <InputX customInputClassName={styles.input} value={value} onInput={handleInput} placeholder="请输入调价价格"></InputX>
            </View>
            {errorMsg && <Text className={styles.errorMsg}>{errorMsg}</Text>}
            <View className={styles.tips}>调价是在标准报价基础上调整，增加价格则输入正数，减少则输入负数</View>
          </View>
          <Divider direction="horizontal" customStyles={{ margin: '0', opacity: '0.7', transform: 'translateY(1px) scaleY(0.6)' }}></Divider>
          <View className={styles.modalButton}>
            <View className={styles['modalButton--cancel']} onClick={handleCancel}>取消</View>
            <Divider direction="vertical" customStyles={{ margin: '0', height: '100rpx', opacity: '0.7', transform: 'scaleX(0.6)' }}></Divider>
            <View className={classnames(styles['modalButton--confirm'], errorMsg && styles.disabled)} onClick={handleConfirm}>确认</View>
          </View>
        </View>
      </Dialog>
    </View>

  )
}
const GoodsItemWithMemo = memo(GoodsItem)

const SubmitOrder = () => {
  const addrssRef = useRef<any>([])
  const pages = Taro.getCurrentPages()
  const currPage = pages[pages.length - 1] // 获取当前页面
  const { fetchData: addressFetch } = MpPurchaserAddressList()
  const router: any = useRouter()
  const [infoObj, setInfoObj] = useState<any>({})
  let selectId = -1

  const isBuyNew = useRef(false)

  // 收货方法,1:自提，2物流
  const [receivingStatus, setReceivingStatus] = useState<any>(null)
  // 切换自提或者物流
  const onReceivingStatus = debounce(async(e, value) => {
    e.stopPropagation()
    if (receivingStatus == value) {
      alert.error('不能选择相同的方式')
      return false
    }
    Taro.showLoading({
      title: '请稍等...',
      mask: true,
    })
    // 判断是否有默认地址
    if (value === 2 && addrssRef.current.length > 0 && !currPage.data?.addressObj) {
      setInfoObj(val => ({
        ...val,
        province_name: addrssRef.current[0]?.province_name,
        address_id: addrssRef.current[0]?.id,
        city_name: addrssRef.current[0]?.city_name,
        address_detail: addrssRef.current[0]?.address_detail,
        district_name: addrssRef.current[0]?.district_name,
        target_user_name: addrssRef.current[0]?.name,
        purchaser_phone: addrssRef.current[0]?.phone,
      }))
    }
    // 没有默认地址提示进去选择地址
    if (value === 2 && !addrssRef.current.length && !infoObj?.province_name) {
      alert.error('请选择地址')
    }
    setReceivingStatus(value)
    Taro.hideLoading()
  }, 300)

  const { fetchData: infoFetch } = MpSaleOrderPreview()
  const [pussName, setPusername] = useState<String>('')
  // 获取订单详情
  const getDetail = async() => {
    let arr: any[] = []
    console.log('purchaser_name', router.params.purchaser_name)
    arr = JSON.parse(decodeURIComponent(router.params.shopping_cart_product_color_list))
    const list: any[] = []
    arr?.forEach((item) => {
      list.push({
        shopping_cart_product_color_id: parseInt(item),
        sale_price: 0,
      })
    })
    const query = {
      purchaser_id: Number(router.params.purchaser_id),
      sale_mode: Number(router.params.sale_mode),
      shopping_cart_product_color_list: list,
    }
    const res = await infoFetch(query)
    setInfoObj({
      ...res.data,
      product_list: res.data.product_list.map((item) => {
        item.product_colors = item.product_colors.map((it) => {
          // 用于存储原始价格，（单价/批量）调整价格
          it.origin_price = it.standard_price
          return it
        })
        return item
      }),
    })
  }

  const { fetchData } = SaleOrderPreViewBuyNow()
  // 立即购买
  const getOnceDetail = async() => {
    const sale_order_product_color_list = JSON.parse(router?.params?.sale_order_product_color_list as string) || []
    if (sale_order_product_color_list?.length > 0) {
      const arr: any[] = []
      const sale_mode = Number(router?.params.sale_mode)
      sale_order_product_color_list.forEach((item) => {
        arr.push({
          length: item?.length || 0,
          roll: item.roll,
          product_color_id: item.id,
          sale_price: sale_mode === EnumSaleMode.Bulk ? item.bulk_price : sale_mode === EnumSaleMode.Plate ? item.length_cut_price : item.weight_cut_price,
        })
      })
      const res = await fetchData({
        sale_mode,
        sale_order_product_color_list: arr,
        purchaser_id: Number(router?.params.purchaser_id),
      })
      setInfoObj({
        ...res.data,
        product_list: res.data.product_list?.map((item) => {
          item.product_colors = item.product_colors.map((it) => {
          // 用于存储原始价格，（单价/批量）调整价格
            it.origin_price = it.standard_price
            return it
          })
          return item
        }),
      })
    }
  }

  // 备注操作
  const [showDesc, setShowDesc] = useState(false)
  const getRemark = useCallback(async(e) => {
    setShowDesc(false)
    setInfoObj(val => ({ ...val, remark: e }))
  }, [])

  const handSelect = (obj) => {
    if (receivingStatus == 1) { return false }
    Taro.navigateTo({
      url: '/pages/addressManager/index?orderId=' + '-100' + `&purchaser_id=${router.params.purchaser_id}`,
    })
  }
  const { openSubscriptionMessage } = UseSubscriptionMessage()

  // 提交订单
  const { fetchData: postFetch } = MpSaleOrderPost()
  const { fetchData: postOnceFetch } = SaleOrderSubmitBuyNow()
  const handSure = () => {
    if (receivingStatus == 2 && !infoObj.address_id) {
      return alert.error('请选择地址')
    }
    const list: any[] = []
    if (!isBuyNew.current) {
      infoObj.product_list.forEach((item) => {
        item.product_colors.forEach((it) => {
          list.push({
            sale_price: Number(it.sale_price),
            shopping_cart_product_color_id: Number(it.id),
          })
        })
      })
    }
    else {
      infoObj.product_list.forEach((item) => {
        item.product_colors.forEach((it) => {
          list.push({
            length: it.length,
            roll: it.roll,
            sale_price: Number(it.sale_price),
            product_color_id: Number(it.id),
          })
        })
      })
    }
    const query = {
      address_id: Number(infoObj.address_id) ? Number(infoObj.address_id) : 0,
      list,
      physical_warehouse: infoObj.physical_warehouse,
      purchaser_id: Number(router.params.purchaser_id),
      remark: infoObj.remark,
      sale_mode: infoObj.sale_mode,
      shipment_mode: receivingStatus,
    }
    Taro.showModal({
      content: '确认提交吗？',
      confirmText: '确认',
      cancelText: '取消',
      async success(res) {
        if (res.confirm) {
          await openSubscriptionMessage({ scenes: 5 })
          Taro.showLoading({
            title: '请稍等...',
            mask: true,
          })
          let res
          if (isBuyNew.current) {
            res = await postOnceFetch(query)
          }
          else {
            res = await postFetch(query)
          }
          if (res?.msg === 'success') {
            Taro.showToast({
              title: '成功',
            })
            Taro.hideLoading()
            Taro.redirectTo({
              url: `/pages/orderDetails/index?id=${res.data.id}`,
            })
          }
          else {
            Taro.hideLoading()
            Taro.showToast({
              title: res?.msg,
              icon: 'error',
            })
          }
        }
      },
    })
  }

  // 获取地址
  const getAddress = async() => {
    const result = await addressFetch({ purchaser_id: router.params.purchaser_id })
    addrssRef.current = result?.data?.list.filter((item) => { return item.is_default })
  }

  useEffect(() => {
    setInfoObj(infoObj)
  }, [infoObj])
  useDidShow(() => {
    // 获取选择的地址

    setInfoObj(val => ({
      ...val,
      sale_mode: Number(router.params.sale_mode),
      province_name: currPage.data?.addressObj?.province_name ? currPage.data?.addressObj?.province_name : '',
      address_id: currPage.data?.addressObj?.id ? currPage.data?.addressObj?.id : '',
      city_name: currPage.data?.addressObj?.city_name ? currPage.data?.addressObj?.city_name : '',
      address_detail: currPage.data?.addressObj?.address_detail ? currPage.data?.addressObj?.address_detail : '',
      district_name: currPage.data?.addressObj?.district_name ? currPage.data?.addressObj?.district_name : '',
      target_user_name: currPage.data?.addressObj?.name ? currPage.data?.addressObj?.name : '',
      purchaser_phone: currPage.data?.addressObj?.phone ? currPage.data?.addressObj?.phone : '',
    }))
    selectId = currPage.data?.addressObj?.id
    const obj = currPage?.data?.ids?.filter((item) => { return item == selectId })
    if (currPage?.data?.ids && obj.length === 0) {
      setInfoObj(val => ({
        ...val,
        sale_mode: Number(router.params.sale_mode),
        province_name: '',
        address_id: '',
        city_name: '',
        address_detail: '',
        district_name: '',
        target_user_name: '',
        purchaser_phone: '',
      }))
    }
    if (!currPage.data?.addressObj) {
      setReceivingStatus(1)
    }
    else {
      setReceivingStatus(2)
    }
  })

  useEffect(() => {
    getAddress()
    console.log('isBuyNew', router.params.isBuyNew)
    setPusername(decodeURIComponent(router.params.purchaser_name))
    isBuyNew.current = JSON.parse(router.params.isBuyNew)
    // 判断立即购买
    if (isBuyNew.current) {
      getOnceDetail()
    }
    else {
      getDetail()
    }
  }, [])

  const updateData = (data: Record<string, any>) => {
    setInfoObj(val => ({
      ...val,
      ...data,
    }))
  }

  return (
    <View className={styles.mainBox}>
      <View className={styles.content}>

        <AddressDetailBox
          navSelect={obj => handSelect(obj)}
          obj={infoObj}
          receivingStatus={receivingStatus}
          onReceivingStatus={(e, value) => onReceivingStatus(e, value)}
        ></AddressDetailBox>
        <DefaultBoxWithMemo
          showMode
          title="客户信息"
          modeName={infoObj.sale_mode_name}
        >
          <View className={styles.pussBox}>
            <View className={styles.pussName}>{pussName}</View>
          </View>
        </DefaultBoxWithMemo>
        <View className={styles.productBox}>
          <GoodsItemWithMemo list={infoObj?.product_list} obj={infoObj} updateData={updateData} ></GoodsItemWithMemo>
          <View className={styles.flexMoney}>
            <View className={styles.flexTotalBox}>
              <View className={styles.totalFont}>合计金额</View>
              <IconFont name="icon-tishi" size={28} ></IconFont>
            </View>
            <View className={styles.shoudPay}>¥{formatPriceDiv(infoObj.estimate_amount, 100, true)}</View>
          </View>
        </View>
        <DefaultBoxWithMemo title="备注信息" showMode modeName={`${'填写/修改备注'} >`} clickNode={() => setShowDesc(true)}>
          <View className={styles.remarkFont}>{!infoObj.remark ? '暂无' : infoObj.remark}</View>
        </DefaultBoxWithMemo>
      </View>
      <View className={styles.bottomBox}>
        <View className={styles.leftBottom}>
          <View className={styles.topFlex}>
            <View className={styles.topFont}>预估金额:</View>
            <View className={styles.topTotal}>¥{formatPriceDiv(infoObj.estimate_amount, 100, true)}</View>
          </View>
          <View className={styles.bottomFlex}>{infoObj.product_list?.length} 种面料，{infoObj.total_colors} 种颜色，共 {infoObj.sale_mode === 0 ? infoObj.total_number : infoObj.total_number / 100} {infoObj.sale_mode === 0 ? '条' : 'm'}</View>
        </View>
        <View className={styles.rightBottom} onClick={handSure}>提交订单</View>
      </View>

      <Popup show={showDesc} showTitle={false} onClose={() => setShowDesc(false)}>
        {
          showDesc && <Remark onSave={e => getRemark(e)} defaultValue={infoObj.remark} />
        }
      </Popup>
    </View>
  )
}
export default SubmitOrder
