import { Button, Image, Input, ScrollView, View } from '@tarojs/components'
import Taro, { useDidShow, useRouter } from '@tarojs/taro'
import { memo, useCallback, useEffect, useMemo, useRef, useState } from 'react'
import classnames from 'classnames'
import styles from './index.module.scss'
import Search from '@/components/search'
import InfiniteScroll from '@/components/infiniteScroll'
import { dataLoadingStatus, getFilterData } from '@/common/util'
import Tag from '@/components/tag'
import { GetWarehouseList } from '@/api/refound'

const WareHousePage = () => {
  const [search, setSearch] = useState({
    name: '',
  })
  const [clentList, setClientlist] = useState<{ list: any[]; total: number }>({ list: [], total: 0 })

  const { fetchData: clitentFetch, state: orderState } = GetWarehouseList()
  // 数据加载状态
  const statusMore = useMemo(() => {
    return dataLoadingStatus({ list: clentList.list, total: clentList.total, status: orderState.loading! })
  }, [clentList, orderState])

  const [clientObj, setclientObj] = useState({
    clientId: null,
    clientName: '',
  })
  // 上拉加载数据
  // const pageNum = useRef({ size: search.size, page: search.page })
  // 输入了搜索关键字
  const getSearchData = useCallback((eq) => {
    // pageNum.current.page = 1
    setClientlist(() => ({ list: [], total: 0 }))
    setSearch(e => ({ ...e, name: eq }))
  }, [])

  const router = useRouter()

  // const getScrolltolower = useCallback(() => {
  //   if (clentList.list.length < clentList.total) {
  //     pageNum.current.page++
  //     const size = pageNum.current.size * pageNum.current.page
  //     setSearch(e => ({ ...e, size }))
  //     console.log(search, 11111)
  //   }
  // }, [clentList])

  // 列表下拉刷新
  const [refresherTriggeredStatus, setRefresherTriggeredStatus] = useState(false)
  const getRefresherRefresh = async() => {
    // pageNum.current.page = 1
    setRefresherTriggeredStatus(true)
    setSearch(val => ({ ...val }))
  }
  const getCuss = async() => {
    const res = await clitentFetch(getFilterData({ name: search.name }))
    if (router?.params.clientId) {
      res.data.list.map((item) => {
        if (item.id == router?.params.clientId) {
          item.checked = true
        }
        else {
          item.checked = false
        }
        return item
      })
    }
    setClientlist(e => ({ ...e, list: res.data?.list, total: res.data?.total }))
    setRefresherTriggeredStatus(false)
  }
  useEffect(() => {
    getCuss()
  }, [search])
  // 选择客户
  const selectClient = (item) => {
    clentList.list.map((it) => {
      if (item.id === it.id) {
        it.checked = true
      }
      else {
        it.checked = false
      }
      return it
    })
    setclientObj(item)
    const pages = Taro.getCurrentPages() // 获取当前的页面栈
    const prevPage = pages[pages.length - 2]
    console.log('prevPage', prevPage)
    prevPage.setData({ // 设置上一个页面的值
      clientId: item.id,
      clientName: item.name,
    })
    setClientlist(e => ({ ...e, list: clentList?.list, total: clentList?.total }))
    Taro.navigateBack({
      delta: 1,
    })
  }
  useEffect(() => {
    if (clientObj?.clientId !== null) {
      setclientObj(clientObj)
    }
  }, [clientObj])
  return (
    <View className={styles.cussBox}>
      <View className={styles.searchBox}>
        <View className={styles.two}>
          <Search placeholder="请输入仓库名称" showBtn={false} changeOnSearch={getSearchData} />
        </View>

      </View>
      <View className={styles.listBox}>
        <InfiniteScroll
          statusMore={statusMore}
          // selfonScrollToLower={getScrolltolower}
          refresherEnabled
          refresherTriggered={refresherTriggeredStatus}
          selfOnRefresherRefresh={getRefresherRefresh}
        >
          {
            clentList.list.map((item, index) => {
              return (
                <View className={classnames(styles.itemBox, item.checked ? styles.acticveitemBox : null)} key={index} onClick={() => { selectClient(item) }}>
                  <View className={styles.cussName}>
                    { item.name }
                  </View>
                </View>
              )
            })
          }
        </InfiniteScroll>
      </View>

    </View>
  )
}

export default WareHousePage
