import { TabBarType } from '../constants/tabbar'
import { checkKey } from '@/common/common'
import type IconFont from '@/components/iconfont/iconfont'

type IconfontName = Parameters<typeof IconFont>['0']['name']

interface TabBarItem {
  id: TabBarIndex
  pagePath: string
  text: string
  iconPath: IconfontName
  selectedIconPath: IconfontName
  key: string
}

type TabBarIndexMap = Record<number, TabBarItem>

export enum TabBarIndex {
  INDEX = 1,
  SHOPPING = 2,
  ORDER = 3,
  USER = 4,
}

export const INITIAL_STATE = {
  selectedId: TabBarIndex.INDEX,
  tabItem: [
    {
      id: TabBarIndex.INDEX,
      pagePath: '/pages/index/index',
      text: '首页',
      iconPath: 'icon-shouye1',
      selectedIconPath: 'icon-shouye',
      key: 'index_page',
    },
    {
      id: TabBarIndex.SHOPPING,
      pagePath: '/pages/shopping/index',
      text: '购物',
      iconPath: 'icon-gouwu1',
      selectedIconPath: 'icon-gouwu',
      key: 'shopping_cart_page',
    },
    {
      id: TabBarIndex.ORDER,
      pagePath: '/pages/order/index',
      text: '订单',
      iconPath: 'icon-dingdan1',
      selectedIconPath: 'icon-dingdan',
      key: 'order_page',
    },
    {
      id: TabBarIndex.USER,
      pagePath: '/pages/user/index',
      text: '我的',
      iconPath: 'icon-gerenzhongxin1',
      selectedIconPath: 'icon-gerenzhongxin',
      key: 'user_page',
    },
  ] as TabBarItem[],
}

export interface TabBarData {
  selectedId?: number
  tabItem?: TabBarIndexMap[number][]
}

export interface TabBarAction {
  type: TabBarType
  data: TabBarData
}
// TabBarReducer
export default (state = INITIAL_STATE, action: TabBarAction) => {
  const { type, data } = action
  switch (type) {
    case TabBarType.SET_SELECTED:
      return {
        ...state,
        selectedId: data.selectedId,
      }
    case TabBarType.SET_TAB_ITEM:
      return {
        ...state,
        tabItem: data.tabItem,
      }
    default:
      return {
        ...state,
        tabItem: INITIAL_STATE.tabItem.filter(item => checkKey(item.key)),
      }
  }
}
